recls

package module
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 20, 2026 License: BSD-3-Clause Imports: 1 Imported by: 0

README

recls.Go

The platform-independent file-system recursive search library, for Go.

Language License GitHub release Last Commit Go Go Reference

Table of contents

Introduction

recls - recursive ls - is a platform-independent recursive file-system search library implemented in C and C++ with a C-API, and a C++ binding. It implemented in several languages: recls.Go is the Go implementation.

recls is completely free and includes source released under a BSD-style license.

Installation


import recls "github.com/synesissoftware/recls.Go"

Examples

Examples are provided in the examples directory, along with a markdown description for each. A detailed list TOC of them is provided in EXAMPLES.md.

Project Information

Where to get help

GitHub Page

Contribution guidelines

Defect reports, feature requests, and pull requests are welcome on https://github.com/synesissoftware/recls.Go.

Dependencies
Development/Example/Testing Dependencies
License

recls.Go is released under the 3-clause BSD license. See LICENSE for details.

Documentation

Index

Constants

const (
	VersionMajor uint16 = 0
	VersionMinor uint16 = 0
	VersionPatch uint16 = 1
	VersionAB    uint16 = ver2go.Release
)

Variables

This section is empty.

Functions

func Version

func Version() uint64

Version returns this library's version as a packed 64-bit integer, formed by ver2go.CombineVersion from VersionMajor, VersionMinor, VersionPatch, and VersionAB. The result is suitable for numeric comparison: a later release has a strictly greater value than an earlier one that uses the same packing.

func VersionString

func VersionString() string

VersionString returns this library's version as a human-readable string, formed by ver2go.CalcVersionString from VersionMajor, VersionMinor, VersionPatch, and VersionAB. For a final (non-prerelease) version the result is of the form "MAJOR.MINOR.PATCH", e.g. "0.0.1".

Types

This section is empty.

Directories

Path Synopsis

Jump to