Documentation
¶
Index ¶
Constants ¶
Variables ¶
This section is empty.
Functions ¶
func Version ¶
func Version() uint64
Version returns this library's version as a packed 64-bit integer, formed by ver2go.CombineVersion from VersionMajor, VersionMinor, VersionPatch, and VersionAB. The result is suitable for numeric comparison: a later release has a strictly greater value than an earlier one that uses the same packing.
func VersionString ¶
func VersionString() string
VersionString returns this library's version as a human-readable string, formed by ver2go.CalcVersionString from VersionMajor, VersionMinor, VersionPatch, and VersionAB. For a final (non-prerelease) version the result is of the form "MAJOR.MINOR.PATCH", e.g. "0.0.1".
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.